#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <QtWebKit/QWebView>
#include <QtWebKit/QWebFrame>
//
#include <QString>
#include <QStringBuilder>
#include <QByteArray>
#include <QtNetwork/QHttp>
#include <QtNetwork/QHttpRequestHeader>
#include <QFile>
#include <iostream>
#include <QtNetwork/QNetworkAccessManager>
#include <QtNetwork/QNetworkReply>

#include <QFile>
#include <QCoreApplication>
#include <QTextStream>



MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{


    ui->setupUi(this);





    //set font and color for the label which shows the default horoscope is set.
    QPalette palette;
    QBrush brush(QColor("green"));
    brush.setStyle(Qt::SolidPattern);
    palette.setBrush(QPalette::Active, QPalette::WindowText, brush);
    palette.setBrush(QPalette::Inactive, QPalette::WindowText, brush);

    ui->defaultLBL->setPalette(palette);
    QFont font;
    font.setPointSize(17);
    font.setBold(true);

    ui->defaultLBL->setFont(font);
    ui->defaultLBL->setAutoFillBackground(true);

    //multiple lines
    ui->defaultLBL->setWordWrap(true);

    //period combobox items
    ui->periodCMBX->addItem("Today","daily-overview");
    ui->periodCMBX->addItem("This Week","weekly-overview");
    ui->periodCMBX->addItem("This Month","monthly-overview");
    ui->periodCMBX->addItem("This Year","yearly-overview");

    //horoscope combobox items
    ui->horoscopeCMBX->addItem("Choose Horoscope...","none");
    ui->horoscopeCMBX->addItem("Aries March 21-April 19","aries");
    ui->horoscopeCMBX->addItem("Taurus April 20-May 20","taurus");
    ui->horoscopeCMBX->addItem("Gemini May 21-June 21","gemini");
    ui->horoscopeCMBX->addItem("Cancer June 22-July 22","cancer");
    ui->horoscopeCMBX->addItem("Leo July 23-August 22","leo");
    ui->horoscopeCMBX->addItem("Virgo August 23-September 22","virgo");
    ui->horoscopeCMBX->addItem("Libra September 23-October 23","libra");
    ui->horoscopeCMBX->addItem("Scorpio October 24-November 21","scorpio");
    ui->horoscopeCMBX->addItem("Sagittarius November 22-December 21","sagittarius");
    ui->horoscopeCMBX->addItem("Capricorn December 22-January 19 , 83","capricorn");
    ui->horoscopeCMBX->addItem("Aquarius January 20-February 18","aquarius");
    ui->horoscopeCMBX->addItem("Pisces February 19-March 20","pisces");

    //connecting Signal and Slots

    connect(ui->displayBTN,SIGNAL(clicked()),this,SLOT(MakeLink()));
    connect(ui->defaultBTN,SIGNAL(clicked()),this,SLOT(setDefaultHoroscope()));

    // a netwrork object for accessing the internet
    manager = new QNetworkAccessManager(this);

    connect(manager, SIGNAL(finished(QNetworkReply*)),this,SLOT(replyFinished(QNetworkReply*)));
    //function call, in order to display the daily horoscope for the pre-set value.
    MakeLink();

 }

MainWindow::~MainWindow()
{
    delete manager;
    delete ui;
}


// ceating a link (url) from the values set by the user.
void MainWindow::MakeLink()
{
    // getting the horoscope and the period(daily,weekly,...).
    QString selectedHoroscope =( ui->horoscopeCMBX->itemData(ui->horoscopeCMBX->currentIndex())).toString();
    QString selectedPeriod =( ui->periodCMBX->itemData(ui->periodCMBX->currentIndex())).toString();

    // if the horoscope is not set, means the application just loaded, then it displays the daily default horoscope
    if(selectedHoroscope=="none")
    {
        QString storedDefaultHoroscope;
        QFile file("out.txt");
        file.open(QIODevice::ReadOnly | QIODevice::Text);
        QTextStream in(&file);
        //read the pre-set value of the horoscope stored in the file.
        storedDefaultHoroscope=in.readLine();
        file.close();
        selectedHoroscope=storedDefaultHoroscope;
    }
    if(selectedHoroscope!="")
    {
        QString link="http://shine.yahoo.com/astrology/"+selectedHoroscope+"/"+selectedPeriod+"/";
        //read the from the yahoo horscope.. with the selected values.
        manager->get(QNetworkRequest(QUrl(link)));
    }




}
// when data is read from internet the below function is executed
void MainWindow::replyFinished(QNetworkReply *my_reply)
{
    QString selectedHoroscope =( ui->horoscopeCMBX->itemData(ui->horoscopeCMBX->currentIndex())).toString();
    QString selectedPeriod =ui->periodCMBX->currentText();

    if(selectedHoroscope=="none")
    {
        QString storedDefaultHoroscope;
        QFile file("out.txt");
        file.open(QIODevice::ReadOnly | QIODevice::Text);
        QTextStream in(&file);
        storedDefaultHoroscope=in.readLine();
        file.close();
        selectedHoroscope=storedDefaultHoroscope;

    }
// read all the data from the page
  QString  my_string=my_reply->readAll();
// this string is to be used for filtering the wanted data
  QString start="content" % QChar('"');

 // specify the start of wanted data
  QStringList mylist= my_string.split(start,QString::SkipEmptyParts);
  QStringList my_list_2;
  //specify the end of wanted data
  my_list_2=mylist[1].split("</p>",QString::SkipEmptyParts);

  QString unformatted=my_list_2[0];
  //more filtering
  QStringList formatted=unformatted.split(("<p>"));

  selectedHoroscope=selectedHoroscope.toUpper();
  QString completeText=selectedHoroscope+" - " +selectedPeriod+"\n\n"+ formatted[1];
  // display the output .
  ui->displayLBL->setText(completeText);

}

// for setting the default horoscope which will be stored in a file.
void MainWindow::setDefaultHoroscope()
{

     QString defaultHoroscope =( ui->horoscopeCMBX->itemData(ui->horoscopeCMBX->currentIndex())).toString();

     if(defaultHoroscope!="none")
     {
        QFile file("out.txt");
        file.open(QIODevice::WriteOnly | QIODevice::Text);

        QTextStream out(&file);
        // write to a file
        out << defaultHoroscope;

        file.close();

        ui->defaultLBL->setText("Your Default Horoscope is successfuly set to:  "+defaultHoroscope);
    }
    else   //no horoscope selected.
    {
        ui->defaultLBL->setText("InCorrect Operation ... Please select a horoscope!!! ");
    }
}






